@@ -226,12 +226,22 @@ function chmod(path2, mode) {
   debug("chmod", path2, mode), import_fs.default.chmodSync(path2, mode);
 }
 __name(chmod, "chmod");
+function exists(path2) {
+  debug("exists", path2);
+  try {
+    return import_fs.default.existsSync(path2);
+  } catch (error2) {
+    debug("fs.existsSync failed", error2);
+  }
+  return !1;
+}
+__name(exists, "exists");
 
 // src/npm/install.ts
 var import_zlib = require("zlib");
 
 // src/platform.ts
-var os2 = process.platform, arch = os2 === "darwin" && process.arch === "x64" && isRosetta2() ? "arm64" : process.arch, avx2 = arch === "x64" && (os2 === "linux" && isLinuxAVX2() || os2 === "darwin" && isDarwinAVX2() || os2 === "win32" && isWindowsAVX2()), platforms = [
+var os2 = process.platform, arch = os2 === "darwin" && process.arch === "x64" && isRosetta2() ? "arm64" : process.arch, avx2 = arch === "x64" && (os2 === "linux" && isLinuxAVX2() || os2 === "darwin" && isDarwinAVX2() || os2 === "win32" && isWindowsAVX2()), abi = os2 === "linux" && isLinuxMusl() ? "musl" : void 0, platforms = [
   {
     os: "darwin",
     arch: "arm64",
@@ -270,6 +280,28 @@ var os2 = process.platform, arch = os2 === "darwin" && process.arch === "x64" &&
     bin: "bun-linux-x64-baseline",
     exe: "bin/bun"
   },
+  {
+    os: "linux",
+    arch: "aarch64",
+    abi: "musl",
+    bin: "bun-linux-aarch64-musl",
+    exe: "bin/bun"
+  },
+  {
+    os: "linux",
+    arch: "x64",
+    abi: "musl",
+    avx2: !0,
+    bin: "bun-linux-x64-musl",
+    exe: "bin/bun"
+  },
+  {
+    os: "linux",
+    arch: "x64",
+    abi: "musl",
+    bin: "bun-linux-x64-musl-baseline",
+    exe: "bin/bun"
+  },
   {
     os: "win32",
     arch: "x64",
@@ -283,7 +315,17 @@ var os2 = process.platform, arch = os2 === "darwin" && process.arch === "x64" &&
     bin: "bun-windows-x64-baseline",
     exe: "bin/bun.exe"
   }
-], supportedPlatforms = platforms.filter((platform) => platform.os === os2 && platform.arch === arch && (!platform.avx2 || avx2)).sort((a, b) => a.avx2 === b.avx2 ? 0 : a.avx2 ? -1 : 1);
+], supportedPlatforms = platforms.filter(
+  (platform) => platform.os === os2 && platform.arch === arch && (!platform.avx2 || avx2) && (!platform.abi || abi === platform.abi)
+).sort((a, b) => a.avx2 === b.avx2 ? 0 : a.avx2 ? -1 : 1);
+function isLinuxMusl() {
+  try {
+    return exists("/etc/alpine-release");
+  } catch (error2) {
+    return debug("isLinuxMusl failed", error2), !1;
+  }
+}
+__name(isLinuxMusl, "isLinuxMusl");
 function isLinuxAVX2() {
   try {
     return read("/proc/cpuinfo").includes("avx2");
@@ -326,7 +368,7 @@ __name(isWindowsAVX2, "isWindowsAVX2");
 function importBun() {
   return __async(this, null, function* () {
     if (!supportedPlatforms.length)
-      throw new Error(`Unsupported platform: ${os2} ${arch}`);
+      throw new Error(`Unsupported platform: ${os2} ${arch} ${abi || ""}`);
     for (let platform of supportedPlatforms)
       try {
         return yield requireBun(platform);
@@ -376,7 +418,7 @@ function installBun(platform, dst) {
     write(join(cwd, "package.json"), "{}");
     let { exitCode } = spawn(
       "npm",
-      ["install", "--loglevel=error", "--prefer-offline", "--no-audit", "--progress=false", `${module2}@1.1.38`],
+      ["install", "--loglevel=error", "--prefer-offline", "--no-audit", "--progress=false", `${module2}@1.1.42`],
       {
         cwd,
         stdio: "pipe",
@@ -397,7 +439,7 @@ function installBun(platform, dst) {
 __name(installBun, "installBun");
 function downloadBun(platform, dst) {
   return __async(this, null, function* () {
-    let tgz = yield (yield fetch(`https://registry.npmjs.org/@oven/${platform.bin}/-/${platform.bin}-1.1.38.tgz`)).arrayBuffer(), buffer;
+    let tgz = yield (yield fetch(`https://registry.npmjs.org/@oven/${platform.bin}/-/${platform.bin}-1.1.42.tgz`)).arrayBuffer(), buffer;
     try {
       buffer = (0, import_zlib.unzipSync)(tgz);
     } catch (cause) {
